@@ -1,6 +1,6 @@
 <?php
 
-# Copyright (c) 2010-2013 Yubico AB
+# Copyright (c) 2010-2015 Yubico AB
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -29,50 +29,55 @@
 
 class Log
 {
+	private $log_levels = array(
+			LOG_EMERG => 'LOG_EMERG',
+			LOG_ALERT => 'LOG_ALERT',
+			LOG_CRIT => 'LOG_CRIT',
+			LOG_ERR => 'LOG_ERR',
+			LOG_WARNING => 'LOG_WARNING',
+			LOG_NOTICE => 'LOG_NOTICE',
+			LOG_INFO => 'LOG_INFO',
+			LOG_DEBUG => 'LOG_DEBUG',
+	);
 
-  function __construct($name='ykval')
-  {
-    $this->name=$name;
-    $this->fields=array();
+	private $fields = array();
 
-    $this->LOG_LEVELS = array(LOG_EMERG=>'LOG_EMERG',
-			      LOG_ALERT=>'LOG_ALERT',
-			      LOG_CRIT=>'LOG_CRIT',
-			      LOG_ERR=>'LOG_ERR',
-			      LOG_WARNING=>'LOG_WARNING',
-			      LOG_NOTICE=>'LOG_NOTICE',
-			      LOG_INFO=>'LOG_INFO',
-			      LOG_DEBUG=>'LOG_DEBUG');
+	public function __construct ($name = 'ykval')
+	{
+		$this->name = $name;
 
-    openlog("ykval", LOG_PID, LOG_LOCAL0);
-  }
+		openlog('ykval', LOG_PID, LOG_LOCAL0);
+	}
 
-  function addField($name, $value)
-  {
-    $this->fields[$name]=$value;
-  }
+	public function addField ($name, $value)
+	{
+		$this->fields[$name] = $value;
+	}
 
-  function log($priority, $message, $arr=null){
-    if (is_array($arr)) {
-      foreach($arr as $key=>$value){
-        if (is_array($value)) {
-          $value = implode(":", $value);
-        }
-	$message.=" $key=$value ";
-      }
-    }
-    # Add fields
-    $msg_fields = "";
-    foreach ($this->fields as $field=>$value) {
-      $msg_fields .= "[" . $value . "] ";
-    }
-    syslog($priority,
-	   $this->LOG_LEVELS[$priority] . ':' .
-	   $this->name . ':' .
-	   $msg_fields .
-	   $message);
-  }
+	public function log ($priority, $message, $extra = NULL)
+	{
+		$prefix = '';
+		foreach ($this->fields as $val)
+			$prefix .= "[$val] ";
 
+		$suffix = '';
+		if (is_array($extra)) {
+			foreach($extra as $key => $value) {
+				if (is_array($value)) {
+					$value = implode(':', $value);
+				}
+				$suffix .= " $key=$value ";
+			}
+		}
+
+		$message = $prefix . $message . $suffix;
+
+		$message = implode(':', array(
+				$this->log_levels[$priority],
+				$this->name,
+				$message
+			));
+
+		syslog($priority, $message);
+	}
 }
-
-?>
